<?php
require_once 'db.php';
session_start();

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $loginInput = htmlspecialchars($_POST['loginInput']);
    $password = htmlspecialchars($_POST['password']);

    $stmt = $conn->prepare("SELECT * FROM users WHERE email = ? OR username = ? OR phone_number = ?");
    $stmt->bind_param("sss", $loginInput, $loginInput, $loginInput);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        if (password_verify($password, $user['password'])) {
            $_SESSION['user_id'] = $user['id'];
            $_SESSION['username'] = $user['username'];
            $_SESSION['email'] = $user['email'];
            header("Location: dashboard.php");
            exit;
        } else {
            $error = "Invalid password. Please try again.";
        }
    } else {
        $error = "Invalid login credentials. Please try again.";
    }

    $stmt->close();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login Page</title>
    <style>
    
        body {
            font-family: 'Arial', sans-serif;
            background: linear-gradient(135deg, #141414, #3e3e3e, #b2945e);
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            color: #fff;
        }

        .login-container {
            background: #202020;
            padding: 30px;
            border-radius: 15px;
            box-shadow: 0px 10px 30px rgba(0, 0, 0, 0.5);
            width: 100%;
            max-width: 450px;
            border: 2px solid #b2945e;
        }

        .logo-container {
            text-align: center;
            margin-bottom: 20px;
        }

        .logo-container img {
            max-width: 100px;
            border-radius: 50%;
            border: 2px solid #b2945e;
        }

        h2 {
            text-align: center;
            color: #b2945e;
            margin-bottom: 10px;
            font-size: 2rem;
        }

        h3 {
            text-align: center;
            color: #dcdcdc;
            margin-bottom: 20px;
            font-size: 1.5rem;
        }

        .form-group {
            margin-bottom: 20px;
        }

        label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
            font-size: 0.9rem;
            color: #dcdcdc;
        }

        input[type="text"], input[type="password"] {
            width: 100%;
            padding: 12px;
            border: 1px solid #555;
            border-radius: 8px;
            font-size: 1rem;
            background-color: #2c2c2c;
            color: #fff;
            transition: all 0.3s ease-in-out;
        }

        input:focus {
            border: 1px solid #b2945e;
            background-color: #333;
            outline: none;
            box-shadow: 0 0 8px rgba(178, 148, 94, 0.5);
        }

        button {
            width: 100%;
            padding: 12px;
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            color: #000;
            font-size: 1.1rem;
            font-weight: bold;
            border: none;
            border-radius: 8px;
            cursor: pointer;
            transition: background 0.3s ease-in-out, transform 0.2s ease;
        }

        button:hover {
            background: linear-gradient(135deg, #ffcc00, #b2945e);
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.5);
            transform: scale(1.05);
        }

        .account-link {
            text-align: center;
            margin-top: 20px;
            font-size: 0.9rem;
            color: #b2945e;
        }

        .account-link a {
            color: #ffcc00;
            text-decoration: none;
            font-weight: bold;
        }

        .account-link a:hover {
            text-decoration: underline;
        }

        .error {
            color: red;
            text-align: center;
            margin-bottom: 10px;
            font-size: 0.9rem;
        }

        @media (max-width: 480px) {
            .login-container {
                padding: 20px;
                border-radius: 10px;
                max-width: 90%;
            }

            h2 {
                font-size: 1.5rem;
            }

            h3 {
                font-size: 1.2rem;
            }
        }

        .forgot-password {
    margin-top: 10px;
    color: #dcdcdc;
    font-size: 0.9rem;
    text-align: center;
}

.forgot-password a {
    color: #ffcc00;
    text-decoration: none;
    font-weight: bold;
    transition: color 0.3s ease;
}

.forgot-password a:hover {
    color: #b2945e;
    text-decoration: underline;
}

    </style>
</head>
<body>
    <div class="login-container">
        <div class="logo-container">
            <img src="./img/icon.png" alt="Logo">
        </div>
        <h2>Login</h2>
        <h3>Welcome Back</h3>
        <?php if (isset($error)): ?>
            <div class="error"><?= $error ?></div>
        <?php endif; ?>
        <form method="POST" action="">
            <div class="form-group">
                <label for="loginInput">Email/Username/Phone Number</label>
                <input type="text" id="loginInput" name="loginInput" placeholder="Enter your email, username, or phone number" required>
            </div>
            <div class="form-group">
                <label for="password">Password</label>
                <input type="password" id="password" name="password" placeholder="Enter your password" required>
            </div>
            <button type="submit">Login</button>
        </form>
        <div class="account-link">
    Don't have an account? <a href="register.php">Register here</a><br>
    <div class="forgot-password">
        <span>Forgot your password?</span> <a href="forgot-password.php">Reset it now</a>
    </div>
</div>

    </div>
</body>
</html>
