<?php
// Start session and include database connection
session_start();
require 'db.php'; // Ensure db.php connects to your database

// Check if user is logged in
$isLoggedIn = isset($_SESSION['user_id']);
$username = $isLoggedIn ? $_SESSION['username'] : ''; // Assume `username` is stored in session
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: #141414;
            color: #fff;
            margin: 0;
            padding: 0;
            overflow-x: hidden;
        }

        .login-page {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
        }

        .login-form {
            background: #1a1a1a;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.5);
            width: 90%;
            max-width: 400px;
        }

        .login-form h2 {
            margin-bottom: 20px;
            color: #ffcc00;
        }

        .login-form input {
            width: 100%;
            padding: 10px;
            margin: 10px 0;
            border: 1px solid #333;
            border-radius: 5px;
            background: #2c2c2c;
            color: #fff;
            font-size: 1rem;
        }

        .login-form button {
            width: 100%;
            padding: 10px;
            background: #ffcc00;
            color: #000;
            border: none;
            border-radius: 5px;
            font-size: 1rem;
            cursor: pointer;
            margin-top: 10px;
            transition: transform 0.2s;
        }

        .login-form button:hover {
            transform: scale(1.05);
        }

        /* Blurred Effect */
        .blurred {
            filter: blur(10px);
            pointer-events: none;
        }

        /* Popup for Logged-in Users */
        .popup-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.8);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 9999;
        }

        .popup {
            background: #202020;
            padding: 30px;
            border-radius: 15px;
            text-align: center;
            color: #fff;
            box-shadow: 0px 10px 30px rgba(0, 0, 0, 0.5);
            width: 90%;
            max-width: 400px;
            border: 2px solid #4caf50;
        }

        .popup h2 {
            margin-bottom: 20px;
            color: #4caf50;
        }

        .popup p {
            margin-bottom: 20px;
        }

        .popup .buttons {
            display: flex;
            justify-content: space-between;
        }

        .popup button {
            padding: 10px 20px;
            border: none;
            border-radius: 5px;
            font-size: 1rem;
            cursor: pointer;
            margin: 10px;
        }

        .popup .dashboard-btn {
            background: #4caf50;
            color: #000;
        }

        .popup .logout-btn {
            background: #ff5722;
            color: #fff;
        }
    </style>
</head>
<body>
    <?php if ($isLoggedIn): ?>
        <!-- Popup for Logged-in Users -->
        <div class="popup-overlay">
            <div class="popup">
                <h2>Welcome, <?= htmlspecialchars($username) ?>!</h2>
                <p class="success-msg" style="color: #4caf50; font-weight: bold;">
                    You are already logged in. You will be redirected to your dashboard shortly.
                </p>
                <div class="buttons">
                    <button class="dashboard-btn" onclick="window.location.href='dashboard.php';">Dashboard</button>
                    <button class="logout-btn" onclick="window.location.href='logout.php';">Logout</button>
                </div>
            </div>
        </div>
        <script>
            // Redirect to dashboard after 5 seconds
            setTimeout(() => {
                window.location.href = 'dashboard.php';
            }, 5000);
        </script>
    <?php endif; ?>

    <!-- Login Page Content -->
    <div class="login-page <?= $isLoggedIn ? 'blurred' : '' ?>">
        <form class="login-form" action="dashboard.php" method="post">
            <h2>Login</h2>
            <input type="text" name="username" placeholder="Username" required>
            <input type="password" name="password" placeholder="Password" required>
            <button type="submit">Login</button>
        </form>
    </div>
</body>
</html>
