<?php
// Start session and include database connection
session_start();
require 'db.php'; // Ensure db.php connects to your database

// Check if user is logged in
$isGuest = !isset($_SESSION['user_id']); // Assume user_id is set during login
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Crypto Dashboard</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: #141414;
            color: #fff;
            margin: 0;
            padding: 0;
            overflow-x: hidden;
        }

        /* Navbar Section */
        .navbar {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 15px 20px;
            background: #1a1a1a;
            border-bottom: 1px solid #333;
            position: relative;
            z-index: 1000;
        }

        .navbar .logo {
            display: flex;
            align-items: center;
            color: #fff;
            font-size: 1.5rem;
            font-weight: bold;
            text-decoration: none;
        }

        .navbar .logo img {
            width: 35px; 
            height: 35px ; 
            margin-right: 10px ;
            border-radius: 50% ;
            border: 10px solid #ffcc00; 
            transition: transform 0.5s ease;
        }

        .navbar .logo img:hover {
            transform: scale(0.9); 
        }


        .navbar .hamburger {
            cursor: pointer;
            display: flex;
            flex-direction: column;
            gap: 5px;
        }

        .navbar .hamburger div {
            width: 25px;
            height: 3px;
            background: #fff;
            transition: all 0.3s ease;
        }

        .navbar .hamburger:hover div {
            background: #ffcc00;
        }

        /* Sidebar Section */
        .sidebar {
            position: fixed;
            top: 0;
            left: -250px;
            width: 250px;
            height: 100%;
            background: #1a1a1a;
            overflow-y: auto;
            transition: left 0.3s ease;
            z-index: 999;
            box-shadow: 2px 0 5px rgba(0, 0, 0, 0.5);
            padding-top: 80px;
        }

        .sidebar ul {
            list-style: none;
            padding: 0;
            margin: 0;
        }

        .sidebar ul li {
            padding: 15px 20px;
            border-bottom: 1px solid #333;
        }

        .sidebar ul li a {
            text-decoration: none;
            color: #fff;
            font-size: 1.2rem;
            display: block;
        }

        .sidebar ul li a:hover {
            background: #333;
        }

        /* Sidebar Active State */
        .sidebar.active {
            left: 0;
        }

        /* Dashboard Container */
        .dashboard-container {
            width: 100%;
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
            border-radius: 15px;
            background: #1a1a1a;
        }

        /* Wallet Balance Section */
        .wallet-balance {
            text-align: center;
            margin: 20px 0;
            background: #2c2c2c;
            border-radius: 10px;
            padding: 20px;
        }

        .wallet-balance h2 {
            font-size: 3rem;
            color: #4caf50;
        }

        .wallet-balance p {
            font-size: 1.2rem;
            color: #bbb;
        }

        .wallet-actions button {
            margin: 10px;
            padding: 10px 20px;
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            border: none;
            border-radius: 8px;
            font-size: 1rem;
            cursor: pointer;
            transition: transform 0.2s;
        }

        .wallet-actions button:hover {
            transform: scale(1.1);
        }

        /* User Cards Section */
        .user-cards {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 20px;
            margin-top: 30px;
        }

        .user-card {
            background: #2c2c2c;
            border-radius: 10px;
            padding: 20px;
            text-align: center;
            transition: transform 0.2s, background-color 0.2s;
        }

        .user-card:hover {
            transform: scale(1.05);
            background: #333;
        }

        .user-card img {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            object-fit: cover;
            margin-bottom: 10px;
        }

        .user-card h3 {
            font-size: 1.2rem;
            margin: 10px 0 5px;
            color: #fff;
        }

        .user-card p {
            font-size: 1rem;
            margin: 5px 0;
            color: #ccc;
        }

        .user-card .price {
            font-size: 1.5rem;
            font-weight: bold;
            color: #4caf50;
        }

        .user-card .price.negative {
            color: #ff5722;
        }

        /* Blurred Effect for Guests */
        .blurred {
            filter: blur(10px);
            pointer-events: none;
        }

        .popup-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.8);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 9999;
        }

        .popup {
            background: #202020;
            padding: 30px;
            border-radius: 15px;
            text-align: center;
            color: #fff;
            box-shadow: 0px 10px 30px rgba(0, 0, 0, 0.5);
            width: 90%;
            max-width: 400px;
            border: 2px solid #b2945e;
        }

        .popup h2 {
            margin-bottom: 20px;
            color: #b2945e;
        }

        .popup p {
            margin-bottom: 20px;
        }

        .popup button {
            padding: 10px 20px;
            margin: 10px;
            border: none;
            border-radius: 5px;
            font-size: 1rem;
            cursor: pointer;
        }

        .popup .register-btn {
            background: #b2945e;
            color: #000;
        }

        .popup .login-btn {
            background: #ffcc00;
            color: #000;
        }
    </style>
</head>
<body>
    <!-- Popup for Guests -->
    <?php if ($isGuest): ?>
        <div class="popup-overlay">
            <div class="popup">
                <h2>Welcome, Guest</h2>
                <p>You must log in or create an account to access the dashboard.</p>
                <button class="register-btn" onclick="window.location.href='register.php';">Register</button>
                <button class="login-btn" onclick="window.location.href='login.php';">Login</button>
            </div>
        </div>
    <?php endif; ?>

    <!-- Navbar Section -->
    <nav class="navbar <?= $isGuest ? 'blurred' : '' ?>">
        <a href="#" class="logo">
            <img src="./img/icon.png" alt="Logo">
            Crypto Dashboard
        </a>
        <div class="hamburger" id="hamburger">
            <div></div>
            <div></div>
            <div></div>
        </div>
    </nav>


    <div class="sidebar" id="sidebar">
        <ul>
            <li><a href="#">Dashboard</a></li>
            <?php if (!$isGuest): ?> <li><a href="settings.php">Settings</a></li>
            
                <li><a href="logout.php">Logout</a></li>
            <?php endif; ?>
        </ul>
    </div>

   
    <div class="dashboard-container <?= $isGuest ? 'blurred' : '' ?>">
       
        <div class="wallet-balance">
            <h2>$0</h2>
            <p>+ $103,760.82 (23,580.67%)</p>
            <div class="wallet-actions">
                <button>Receive</button>
                <button>Buy</button>
                <button>Send</button>
            </div>
        </div>

       
        <div class="user-cards">
      
            <div class="user-card">
                <img src="./icons/bnb.png" alt="User 1">
                <h3>BNB</h3>
                <p>13.24M BNB</p>
                <p class="price">+$103,773.10</p>
            </div>

            <div class="user-card">
                <img src="./icons/doge.png" alt="User 2">
                <h3>Solana</h3>
                <p>3.78211 DOG</p>
                <p class="price negative">-$12.57</p>
            </div>

          
            <div class="user-card">
                <img src="./icons/btc.png" alt="User 3">
                <h3>Bitcoin</h3>
                <p>2.35 BTC</p>
                <p class="price">+$15,000.00</p>
            </div>

           
            <div class="user-card">
                <img src="./icons/eth.png" alt="User 4">
                <h3>Ethereum</h3>
                <p>5.782 ETH</p>
                <p class="price">+$3,450.20</p>
            </div>

         
            <div class="user-card">
                <img src="./icons/usdt.png" alt="User 5">
                <h3>Tether</h3>
                <p>10,000 USDT</p>
                <p class="price">$10,000.00</p>
            </div>

            <div class="user-card">
                <img src="./icons/xrp.png" alt="User 6">
                <h3>Cardano</h3>
                <p>1,234 XRP</p>
                <p class="price">+$520.30</p>
            </div>
        </div>
    </div>
    </div>

    <script>
        // Hamburger Menu Toggle Functionality
        const hamburger = document.getElementById('hamburger');
        const sidebar = document.getElementById('sidebar');

        hamburger.addEventListener('click', () => {
            sidebar.classList.toggle('active');
        });
    </script>
</body>
</html>
