<?php
require_once 'db.php';
require 'composer/vendor/autoload.php'; // Ensure PHPMailer is loaded

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $email = htmlspecialchars($_POST['email']);

    // Prepare SQL query to check if the email exists
    $stmt = $conn->prepare("SELECT * FROM users WHERE email = ?");
    
    if ($stmt === false) {
        die('MySQL prepare error: ' . $conn->error);
    }

    $stmt->bind_param("s", $email);

    if (!$stmt->execute()) {
        die('Execute failed: ' . $stmt->error);
    }

    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // Generate a unique reset token
        $token = bin2hex(random_bytes(16));
        $expiry = date('Y-m-d H:i:s', strtotime('+1 hour'));

        $updateStmt = $conn->prepare("UPDATE users SET reset_token = ?, token_expiry = ? WHERE email = ?");
        
        if ($updateStmt === false) {
            die('MySQL prepare error: ' . $conn->error);
        }

        $updateStmt->bind_param("sss", $token, $expiry, $email);
        
        if (!$updateStmt->execute()) {
            die('Execute failed: ' . $updateStmt->error);
        }

        // Send the reset link via email
        $resetLink = "http://127.0.0.1/reset-password.php?token=$token";
        $subject = "Password Reset Request";
        $message = "Click the link below to reset your password:\n\n$resetLink\n\nThis link is valid for 1 hour.";

        // Configure PHPMailer
        $mail = new PHPMailer(true);
        try {
            // Server settings
            $mail->isSMTP();
            $mail->Host = 'smtp.gmail.com';
            $mail->SMTPAuth = true;
            $mail->Username = 'pndu272@gmail.com'; // Your Gmail address
            $mail->Password = 'txin lhun scxu wjon'; // Your Gmail app password
            $mail->SMTPSecure = PHPMailer::ENCRYPTION_STARTTLS;
            $mail->Port = 587;

            // Recipients
            $mail->setFrom('pndu272@gmail.com', 'pcyberwallet'); // Your email and name
            $mail->addAddress($email);

            // Content
            $mail->isHTML(true);
            $mail->Subject = $subject;
            $mail->Body = nl2br($message); // Convert newlines to <br> for HTML
            $mail->AltBody = $message; // Plain text fallback

            $mail->send();
            $success = "A password reset link has been sent to your email.";
        } catch (Exception $e) {
            $error = "Message could not be sent. Mailer Error: {$mail->ErrorInfo}";
        }
    } else {
        $error = "No account found with that email address.";
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Forgot Password</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: linear-gradient(135deg, #141414, #3e3e3e, #b2945e);
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            color: #fff;
        }

        .forgot-container {
            background: #202020;
            padding: 30px;
            border-radius: 15px;
            box-shadow: 0px 10px 30px rgba(0, 0, 0, 0.5);
            width: 100%;
            max-width: 450px;
            border: 2px solid #b2945e;
        }

        h2 {
            text-align: center;
            color: #b2945e;
            margin-bottom: 20px;
            font-size: 2rem;
        }

        .form-group {
            margin-bottom: 20px;
        }

        label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
            font-size: 0.9rem;
            color: #dcdcdc;
        }

        input[type="email"] {
            width: 100%;
            padding: 12px;
            border: 1px solid #555;
            border-radius: 8px;
            font-size: 1rem;
            background-color: #2c2c2c;
            color: #fff;
            transition: all 0.3s ease-in-out;
        }

        input:focus {
            border: 1px solid #b2945e;
            background-color: #333;
            outline: none;
            box-shadow: 0 0 8px rgba(178, 148, 94, 0.5);
        }

        button {
            width: 100%;
            padding: 12px;
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            color: #000;
            font-size: 1.1rem;
            font-weight: bold;
            border: none;
            border-radius: 8px;
            cursor: pointer;
            transition: background 0.3s ease-in-out, transform 0.2s ease;
        }

        button:hover {
            background: linear-gradient(135deg, #ffcc00, #b2945e);
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.5);
            transform: scale(1.05);
        }

        .message {
            text-align: center;
            margin-top: 20px;
            font-size: 0.9rem;
        }

        .message.success {
            color: #4caf50;
        }

        .message.error {
            color: red;
        }
    </style>
</head>
<body>
    <div class="forgot-container">
        <h2>Forgot Password</h2>
        <?php if (isset($success)): ?>
            <div class="message success"><?= $success ?></div>
        <?php elseif (isset($error)): ?>
            <div class="message error"><?= $error ?></div>
        <?php endif; ?>
        <form method="POST" action="">
            <div class="form-group">
                <label for="email">Enter Your Email Address</label>
                <input type="email" id="email" name="email" placeholder="Enter your email" required>
            </div>
            <button type="submit">Send Reset Link</button>
        </form>
    </div>
</body>
</html>
