<?php
require_once 'db.php';

if (isset($_GET['token'])) {
    $token = $_GET['token'];

    // Verify the token and check if it's expired
    $stmt = $conn->prepare("SELECT * FROM users WHERE reset_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        $expiry = $user['token_expiry'];

        // Check if token has expired
        if (strtotime($expiry) > time()) {
            if ($_SERVER["REQUEST_METHOD"] == "POST") {
                $newPassword = password_hash($_POST['newPassword'], PASSWORD_BCRYPT);
                
                // Update password and clear token
                $updateStmt = $conn->prepare("UPDATE users SET password = ?, reset_token = NULL, token_expiry = NULL WHERE reset_token = ?");
                $updateStmt->bind_param("ss", $newPassword, $token);
                $updateStmt->execute();

                $success = "Your password has been successfully reset. You can now log in.";
            }
        } else {
            $error = "This reset link has expired. Please request a new one.";
        }
    } else {
        $error = "Invalid or expired reset token.";
    }
} else {
    header("Location: login.php");
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Password</title>
    <style>
        body {
            font-family: 'Arial', sans-serif;
            background: linear-gradient(135deg, #141414, #3e3e3e, #b2945e);
            margin: 0;
            padding: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            color: #fff;
        }

        .reset-container {
            background: #202020;
            padding: 30px;
            border-radius: 15px;
            box-shadow: 0px 10px 30px rgba(0, 0, 0, 0.5);
            width: 100%;
            max-width: 450px;
            border: 2px solid #b2945e;
        }

        h2 {
            text-align: center;
            color: #b2945e;
            margin-bottom: 20px;
            font-size: 2rem;
        }

        .form-group {
            margin-bottom: 20px;
        }

        label {
            display: block;
            margin-bottom: 8px;
            font-weight: bold;
            font-size: 0.9rem;
            color: #dcdcdc;
        }

        input[type="password"] {
            width: 100%;
            padding: 12px;
            border: 1px solid #555;
            border-radius: 8px;
            font-size: 1rem;
            background-color: #2c2c2c;
            color: #fff;
            transition: all 0.3s ease-in-out;
        }

        input:focus {
            border: 1px solid #b2945e;
            background-color: #333;
            outline: none;
            box-shadow: 0 0 8px rgba(178, 148, 94, 0.5);
        }

        button {
            width: 100%;
            padding: 12px;
            background: linear-gradient(135deg, #b2945e, #ffcc00);
            color: #000;
            font-size: 1.1rem;
            font-weight: bold;
            border: none;
            border-radius: 8px;
            cursor: pointer;
            transition: background 0.3s ease-in-out, transform 0.2s ease;
        }

        button:hover {
            background: linear-gradient(135deg, #ffcc00, #b2945e);
            box-shadow: 0 4px 10px rgba(0, 0, 0, 0.5);
            transform: scale(1.05);
        }

        .message {
            text-align: center;
            margin-top: 20px;
            font-size: 0.9rem;
        }

        .message.success {
            color: #4caf50;
        }

        .message.error {
            color: red;
        }
    </style>
</head>
<body>
    <div class="reset-container">
        <h2>Reset Your Password</h2>
        <?php if (isset($success)): ?>
            <div class="message success"><?= $success ?></div>
        <?php elseif (isset($error)): ?>
            <div class="message error"><?= $error ?></div>
        <?php endif; ?>
        <form method="POST" action="">
            <div class="form-group">
                <label for="newPassword">New Password</label>
                <input type="password" id="newPassword" name="newPassword" placeholder="Enter new password" required>
            </div>
            <button type="submit">Reset Password</button>
        </form>
    </div>
</body>
</html>
